@@ -164,10 +164,7 @@ class BaseService:
                 'The service url shouldn\'t start or end with curly brackets or quotes. '
                 'Be sure to remove any {} and \" characters surrounding your service url'
             )
-        if service_url is not None:
-            self.service_url = service_url.rstrip('/') # remove trailing slash
-        else:
-            self.service_url = None
+        self.service_url = service_url
 
     def get_authenticator(self) -> Authenticator:
         """Get the authenticator currently used by the service.
